package com.example.demo.supply.Order;

import com.example.demo.supply.Product.Product;
import com.example.demo.supply.Product.ProductService;
import com.example.demo.supply.Supplier.SupplierService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.sql.Date;
import java.util.List;
import java.util.Optional;

@Service
public class OrderService {

    private final OrderRepository orderRepository;
    private final ProductService productService;
    private final SupplierService supplierService;

    public OrderService(OrderRepository orderRepository,
                        ProductService productService,
                        SupplierService supplierService)
    {
        this.orderRepository = orderRepository;
        this.productService = productService;
        this.supplierService = supplierService;
    }

    @Transactional
    public _Order addOrder(Long supplierId){
        final _Order order = new _Order(new Date(System.currentTimeMillis()));
        order.setSupplier(supplierService.findSupplier(supplierId));
        return orderRepository.save(order);
    }

    //поставщики, у которых есть заказ на конкретный товар или несколько товаров
//    @Transactional
//    public List<Supplier> suppliers(List<Product> products){
//        return em.createQuery("SELECT distinct o.supplier FROM Orders o join Product p where p in (:products) ", Supplier.class)
//                .setParameter("products", products).getResultList();
//    }

    @Transactional
    public _Order addProduct(Long id, Long productId) {
        final _Order currentOrder = findOrder(id);
        currentOrder.addProduct(productService.findProduct(productId));
        return orderRepository.save(currentOrder);
    }

    @Transactional
    public _Order removeProduct(Long id, Long productId) {
        final _Order currentOrder = findOrder(id);
        currentOrder.addProduct(productService.findProduct(productId));
        return orderRepository.save(currentOrder);
    }

    @Transactional(readOnly = true)
    public _Order findOrder(Long id) {
        final Optional<_Order> order = orderRepository.findById(id);
        return order.orElseThrow(() -> new OrderNotFoundException(id));
    }

    @Transactional(readOnly = true)
    public List<_Order> findAllOrders() {
        return orderRepository.findAll();
    }

    @Transactional(readOnly = true)
    public List<Product> findAllOrderProducts(Long orderId) {
        final Optional<_Order> order = orderRepository.findById(orderId);
        return order.orElseThrow(() -> new OrderNotFoundException(orderId)).getProducts();
    }

    @Transactional
    public _Order deleteOrder(Long id) {
        final _Order currentOrder = findOrder(id);
        orderRepository.delete(currentOrder);
        return currentOrder;
    }

    @Transactional
    public void deleteAll(){
        orderRepository.deleteAll();
    }
}
